@@ -10,12 +10,12 @@ function timerIncrement() {
     }
 }
 
-(function () {
+(function() {
     setInterval(timerIncrement, 60000);
-    $(this).mousemove(function (e) {
+    $(this).mousemove(function(e) {
         idleTime = 0;
     });
-    $(this).keypress(function (e) {
+    $(this).keypress(function(e) {
         idleTime = 0;
     });
 })();
@@ -35,7 +35,7 @@ function submitNote() {
         webix.ajax().post("/wp-json/click-collect/v1/add-note/", {
             action: "note",
             formValues
-        }, function (text, data, xhr) {
+        }, function(text, data, xhr) {
             if (data.json() === 'success') {
                 webix.message({type: "message-style", text: "Comment added"});
                 var note = {note_content: formValues.note};
@@ -47,23 +47,23 @@ function submitNote() {
     }
 }
 
-function markNew(value, config){
+function markNew(value, config) {
     if (value === "New Order")
-        return { "border":"1px solid #ea7600 !important" };
+        return {"border": "1px solid #ea7600 !important"};
     return value;
 };
 
-(function () {
+(function() {
 
     let newOrderCount = 0;
     let readyOrderCount = 0;
     let toMakeCount = 0;
     let collectedCount = 0;
 
-    jQuery.each(data, function (i, val) {
+    jQuery.each(data, function(i, val) {
 
         let dashReady = 0
-        jQuery.each(val.orders, function (i, val) {
+        jQuery.each(val.orders, function(i, val) {
             if (val.status === '1') {
                 newOrderCount++;
                 dashReady++;
@@ -134,7 +134,7 @@ function markNew(value, config){
                                 fillspace: true,
                                 editor: 'richselect',
                                 options: order_status,
-                                cssFormat:markNew
+                                cssFormat: markNew
                             },
                             {
                                 id: "shop_order_number",
@@ -146,24 +146,24 @@ function markNew(value, config){
                             {
                                 id: "action", header: "Action",
                                 fillspace: true,
-                                template: function (obj) {
+                                template: function(obj) {
                                     return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><button class='view_order'> View Order</button></div>";
                                 },
                                 width: 250
                             }
                         ],
                         on: {
-                            "onAfterEditStop": function (state, editor, ignoreUpdate) {
+                            "onAfterEditStop": function(state, editor, ignoreUpdate) {
                                 if (state.value !== state.old) {
                                     //// UPDATE SHOP ORDER NUMBER /////
                                     if (editor.column === 'shop_order_number') {
-                                        webix.ajax("/wp-json/click-collect/v1/set-shop-order-number/" + state.value + '/' + editor.row, function (text, data, xhr) {
+                                        webix.ajax("/wp-json/click-collect/v1/set-shop-order-number/" + state.value + '/' + editor.row, function(text, data, xhr) {
                                             webix.message({type: "message-style", text: "Shop number saved"});
                                         });
                                     }
                                     //// UPDATE SHOP ORDER STATUS /////
                                     if (editor.column === 'status') {
-                                        webix.ajax("/wp-json/click-collect/v1/update-order-status/" + state.value + '/' + editor.row, function (text, data, xhr) {
+                                        webix.ajax("/wp-json/click-collect/v1/update-order-status/" + state.value + '/' + editor.row, function(text, data, xhr) {
                                             console.log(state.value);
                                             if (text === '"Order not Updated, please check you have input the shop number and final price"') {
                                                 webix.message({type: "message-style", text: text});
@@ -184,9 +184,9 @@ function markNew(value, config){
                             {name: 'red', css: "cancelled"}
                         ],
                         onClick: {
-                            "add_notes": function (e, id, trg) {
+                            "add_notes": function(e, id, trg) {
                                 webix.message({type: "message-style", text: "Loading notes for order: " + id});
-                                webix.ajax("/wp-json/click-collect/v1/get-notes/" + id, function (text, data, xhr) {
+                                webix.ajax("/wp-json/click-collect/v1/get-notes/" + id, function(text, data, xhr) {
                                     windowInfo = data.json();
                                     if (windowInfo) {
                                         webix.ui({
@@ -219,7 +219,7 @@ function markNew(value, config){
                                                         ],
                                                         data: windowInfo,
                                                         on: {
-                                                            "onresize": function () {
+                                                            "onresize": function() {
                                                                 this.adjustRowHeight();
                                                             }
                                                         }
@@ -254,12 +254,12 @@ function markNew(value, config){
                                     }
                                 });
                             },
-                            "view_order": function (e, id, trg) {
+                            "view_order": function(e, id, trg) {
                                 var item = this.getItem(id);
                                 webix.message({type: "message-style", text: "Loading order: " + id});
-                                webix.ajax("/wp-json/click-collect/v1/get-orders/" + id, function (text, data, xhr) {
+                                webix.ajax("/wp-json/click-collect/v1/get-orders/" + id, function(text, data, xhr) {
                                     windowInfo = data.json();
-                                    console.log(windowInfo);
+                                    console.log(windowInfo.coupons.length);
                                     if (windowInfo) {
                                         webix.ui({
                                             view: "window",
@@ -278,7 +278,7 @@ function markNew(value, config){
                                             move: true,
                                             modal: true,
                                             body: {
-                                                width:1000,
+                                                width: 1000,
                                                 rows: [
                                                     {
                                                         height: 250,
@@ -308,6 +308,28 @@ function markNew(value, config){
                                                                         borderless: true,
                                                                         autoheight: true
                                                                     },
+                                                                    {
+                                                                        template: function() {
+                                                                            if (windowInfo.coupons !== "undefined" && windowInfo.coupons.length !== 0) {
+                                                                                return '<strong>Coupon: ' + windowInfo.coupons.description + '</strong>'
+                                                                            } else {
+                                                                                return '';
+                                                                            }
+                                                                        },
+                                                                        borderless: true,
+                                                                        autoheight: true
+                                                                    },
+                                                                    {
+                                                                        template: function() {
+                                                                            if (windowInfo.coupons !== "undefined" && windowInfo.coupons.length !== 0) {
+                                                                                return '<strong>Coupon Amount: ' + windowInfo.coupons.amount + '</strong>'
+                                                                            } else {
+                                                                                return '';
+                                                                            }
+                                                                        },
+                                                                        borderless: true,
+                                                                        autoheight: true
+                                                                    },
                                                                     {},
                                                                     {},
                                                                     {
@@ -361,11 +383,11 @@ function markNew(value, config){
                                                                     {
                                                                         borderless: true,
                                                                         autoheight: true,
-                                                                        template: function (obj) {
-                                                                            return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-single-order.php?location=" + getUrlParameter('location') + "&order="+item.id+"&date=" + i + "'>Print Order</a></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-label.php?shopNo="+$$('shop_number').getValue()+"&number=" + item.contact_number + "&client="+item.client_name+"&date=" + i + "&location="+getUrlParameter('location')+"'>Print Label</a></div>";
+                                                                        template: function(obj) {
+                                                                            return "<div class='webix_el_button'><button class='add_notes'> Add Notes</button></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-single-order.php?location=" + getUrlParameter('location') + "&order=" + item.id + "&date=" + i + "'>Print Order</a></div><div class='webix_el_button'><a class='print_order' href='/content/plugins/click-collect-plugin/templates/print-label.php?shopNo=" + $$('shop_number').getValue() + "&number=" + item.contact_number + "&client=" + item.client_name + "&date=" + i + "&location=" + getUrlParameter('location') + "'>Print Label</a></div>";
                                                                         },
                                                                         onClick: {
-                                                                            "print_label": function (e, id, trg) {
+                                                                            "print_label": function(e, id, trg) {
                                                                                 var orderNo = $$('shop_number').getValue();
                                                                                 console.log(orderNo);
                                                                                 $$('print_order_number').setValue(orderNo);
@@ -375,12 +397,12 @@ function markNew(value, config){
                                                                                     paper: 'a4'
                                                                                 });
                                                                             },
-                                                                            "add_notes": function (e, id, trg) {
+                                                                            "add_notes": function(e, id, trg) {
                                                                                 webix.message({
                                                                                     type: "message-style",
                                                                                     text: "Loading notes for order: " + item.id
                                                                                 });
-                                                                                webix.ajax("/wp-json/click-collect/v1/get-notes/" + item.id, function (text, data, xhr) {
+                                                                                webix.ajax("/wp-json/click-collect/v1/get-notes/" + item.id, function(text, data, xhr) {
                                                                                     windowInfo = data.json();
                                                                                     if (windowInfo) {
                                                                                         webix.ui({
@@ -400,7 +422,7 @@ function markNew(value, config){
                                                                                             modal: true,
                                                                                             position: "center",
                                                                                             width: 1200,
-                                                                                            height:500,
+                                                                                            height: 500,
                                                                                             borderless: true,
                                                                                             body: {
                                                                                                 rows: [
@@ -420,7 +442,7 @@ function markNew(value, config){
                                                                                                         ],
                                                                                                         data: windowInfo,
                                                                                                         on: {
-                                                                                                            "onresize": function () {
+                                                                                                            "onresize": function() {
                                                                                                                 this.adjustRowHeight();
                                                                                                             }
                                                                                                         }
@@ -462,7 +484,7 @@ function markNew(value, config){
                                                                     {
                                                                         css: 'hidden_window',
                                                                         id: 'label_window',
-                                                                        width:3000,
+                                                                        width: 3000,
                                                                         height: 1,
                                                                         rows: [
                                                                             {
@@ -474,23 +496,23 @@ function markNew(value, config){
                                                                                 labelWidth: 175,
                                                                             },
                                                                             {
-                                                                                template: '<p><strong>Phone Number: </strong>' + item.contact_number+'</p>',
+                                                                                template: '<p><strong>Phone Number: </strong>' + item.contact_number + '</p>',
                                                                                 borderless: true,
                                                                                 height: 140,
-                                                                                width:3000
+                                                                                width: 3000
 
                                                                             },
                                                                             {
-                                                                                template: '<p><strong>Client Name: </strong>' + item.client_name+'</p>',
+                                                                                template: '<p><strong>Client Name: </strong>' + item.client_name + '</p>',
                                                                                 borderless: true,
                                                                                 height: 140,
-                                                                                width:3000
+                                                                                width: 3000
                                                                             },
                                                                             {
-                                                                                template: '<p><strong>Collection Date: </strong>' + val.date+'</p>',
+                                                                                template: '<p><strong>Collection Date: </strong>' + val.date + '</p>',
                                                                                 borderless: true,
                                                                                 height: 140,
-                                                                                width:3000
+                                                                                width: 3000
                                                                             },
 
                                                                         ]
@@ -525,23 +547,23 @@ function markNew(value, config){
                                                             {
                                                                 id: 'product_thumbnail',
                                                                 header: '',
-                                                                template: function (obj) {
+                                                                template: function(obj) {
                                                                     return "<img style='display:block; ' src='" + obj.product_thumbnail + "'/>";
                                                                 },
-                                                                autowidth:true,
-                                                                css:'hidden-column'
+                                                                autowidth: true,
+                                                                css: 'hidden-column'
                                                             },
                                                             {
                                                                 id: 'product_title',
                                                                 header: 'Product Title',
                                                                 css: 'print-column',
-                                                                fillspace:true
+                                                                fillspace: true
                                                             },
                                                             {id: 'weight', header: 'Weight (g)', css: 'print-column'},
                                                             {
                                                                 id: 'unit_label',
                                                                 header: 'Unit Label',
-                                                                fillspace:true,
+                                                                fillspace: true,
                                                                 css: 'print-column'
                                                             },
                                                             {
@@ -549,13 +571,18 @@ function markNew(value, config){
                                                                 header: 'Units',
                                                                 css: 'print-column'
                                                             },
-                                                            {id: 'size', header: 'by Pack Size', fillspace:true, css: 'print-column'},
+                                                            {
+                                                                id: 'size',
+                                                                header: 'by Pack Size',
+                                                                fillspace: true,
+                                                                css: 'print-column'
+                                                            },
                                                             {id: 'qty', header: 'Qty', css: 'print-column'},
                                                             {id: 'sku', header: 'SKU', css: 'print-column'},
                                                             {width: 50}
                                                         ],
-                                                        fixedRowHeight:false,
-                                                        rowLineHeight:25,
+                                                        fixedRowHeight: false,
+                                                        rowLineHeight: 25,
                                                         data: windowInfo.orders
                                                     }
                                                 ]
@@ -563,8 +590,8 @@ function markNew(value, config){
 
                                         });
                                         $$("order_window").show();
-                                        $$("shop_number").attachEvent("onBlur", function () {
-                                            webix.ajax("/wp-json/click-collect/v1/set-shop-order-number/" + $$('shop_number').getValue() + '/' + id, function (text, data, xhr) {
+                                        $$("shop_number").attachEvent("onBlur", function() {
+                                            webix.ajax("/wp-json/click-collect/v1/set-shop-order-number/" + $$('shop_number').getValue() + '/' + id, function(text, data, xhr) {
                                                 var record = $$("box" + i);
                                                 var item = record.getItem(id);
                                                 item['shop_order_number'] = $$('shop_number').getValue();
@@ -573,7 +600,7 @@ function markNew(value, config){
 
                                             });
                                         });
-                                        $$("final_price").attachEvent("onBlur", function () {
+                                        $$("final_price").attachEvent("onBlur", function() {
                                             console.log($$('final_price').getValue());
                                             formValues = $$('final_price').getValue();
                                             console.log($$('final_price').getValue());
@@ -582,15 +609,15 @@ function markNew(value, config){
                                                     action: "finalPrice",
                                                     formValues,
                                                     id
-                                                }, function (text, data, xhr) {
+                                                }, function(text, data, xhr) {
                                                     webix.message({type: "message-style", text: "Final Price saved"});
 
                                                 });
                                             }
                                         });
 
-                                        $$("status_select").attachEvent("onChange", function () {
-                                            webix.ajax("/wp-json/click-collect/v1/update-order-status/" + $$('status_select').getValue() + '/' + id, function (text, data, xhr) {
+                                        $$("status_select").attachEvent("onChange", function() {
+                                            webix.ajax("/wp-json/click-collect/v1/update-order-status/" + $$('status_select').getValue() + '/' + id, function(text, data, xhr) {
                                                 if (text === '"Order not Updated, please check you have input the shop number and final price"') {
                                                     webix.message({type: "message-style", text: text});
                                                 } else {
@@ -608,7 +635,7 @@ function markNew(value, config){
                 {height: 35}
             ]
         };
-        webix.ready(function () {
+        webix.ready(function() {
             webix.ui(grid);
         });
 
