@@ -272,8 +272,12 @@ class OrderController
 
         $shipping = self::getShippingDetails($order);
 
+        $coupons = self::getCoupons($orderId);
+
         $orderItems['pickup_date'] = $shipping['Pickup Date'];
         $orderItems['price'] = $order->get_total();
+        $orderItems['coupons'] = $coupons;
+
 
         $orderItems['orders'] = [];
         foreach ($order->get_items() as $itemKey => $item) {
@@ -285,6 +289,30 @@ class OrderController
         return $orderItems;
     }
 
+    public static function getCoupons($orderId)
+    {
+        $order = wc_get_order($orderId);
+        $couponArray = [];
+
+        foreach ($order->get_used_coupons() as $couponName) {
+            $couponObject = get_page_by_title($couponName, OBJECT, 'shop_coupon');
+            $couponID = $couponObject->ID;
+            $couponObject = new \WC_Coupon($couponID);
+
+            $couponArray['title'] = $couponObject->get_code();
+            $couponArray['description'] = $couponObject->get_description();
+            if ($couponObject->get_discount_type() == 'percent') {
+                $couponArray['amount'] = $couponObject->get_amount().'%';
+            } else {
+                $couponArray['amount'] = '£'.$couponObject->get_amount();
+            }
+
+        }
+        return $couponArray;
+
+    }
+
+
     public static function setShopNumber($data)
     {
         $shopNumber = $data->get_params()['shopNumber'];
@@ -381,31 +409,43 @@ class OrderController
             $orderItems[] = $newOrderItem->newOrderItemData();
         };
 
+        $date = strtotime($shipping['Pickup Date']);
+
         $to = $order->getEmail();
         $subject = 'Your Simon Howie Order is ready to collect at our ' . $shipping['Pickup Location'] . ' branch';
         $message = '
+            <div style="background-color:#f7f7f7;padding:10px 100px;text-align:center;">
+            <img src="https://s3-eu-west-1.amazonaws.com/blue2digital/pex/simonhowie/2019/05/02152443/SimonHowie-logo-on-white.png" style="text-align:center;display:block;width:300px;padding:15px;height:auto;margin:15px auto;" alt="Simon Howie Logo">        
+            <div style="background-color:#ea7600;width:100%;color:#fff;font-size:28px;text-align:center;padding:10px 0;">Your Simon Howie Order</div>
+            <div style="background-color:#fff; padding:10px; text-align:left;">
             Dear ' . $order->getName() . '<br>
-            Your order from Simon Howie is now ready to collect at ' . $shipping['Pickup Location'] . '<br>
-            Your shop order number is ' . $shopNumber[0] . ' please quote this when collecting your order.<br>
+            This is to confirm your order will be ready to collect as requested on ' . date('l jS \of F Y', $date) . ' at ' . $shipping['Pickup Location'] . '<br>
+            Your shop order number is <strong style="color:#ea7600;">' . $shopNumber[0] . '</strong> please quote this when collecting your order.<br>
 
-            The final price for the order is: £' . $finalPrice . '';
+            The final price for the order is: <strong style="color:#ea7600;">£' . $finalPrice . '</strong>';
 
-        $message .= '<table style="padding:25px 0;">';
+        $message .= '<table style="border-collapse: collapse;padding:25px 0;">';
         $message .= '<thead style="font-weight:bold;">';
-        $message .= '<tr style="border-bottom:1px solid #000;">';
-        $message .= '<td style="font-weight:bold;">Product Title</td><td>Weight (g)</td><td>Unit Label</td><td>Units</td><td>Pack Size</td><td>Qty</td>';
+        $message .= '<tr style="border-bottom:1px solid #000; color: #ea7600;">';
+        $message .= '<td style="padding:10px;font-weight:bold;border:1px solid #ddd;">Product Title</td><td style="padding:10px;border:1px solid #ddd;">Weight (g)</td><td style="padding:10px;border:1px solid #ddd;">Pack Size</td><td style="padding:10px;border:1px solid #ddd;">Qty</td>';
         $message .= '</tr>';
         $message .= '</thead>';
         $message .= '<tbody>';
         foreach ($orderItems as $orderItem) {
             $message .= '<tr>';
-            $message .= '<td>' . $orderItem['product_title'] . '</td><td>' . $orderItem['weight'] . '</td><td>' . $orderItem['unit_label'] . '</td><td>' . $orderItem['unit'] . '</td><td>' . $orderItem['size'] . '</td><td>' . $orderItem['qty'] . '</td>';
+            $message .= '<td style="padding:10px;border:1px solid #ddd;">' . $orderItem['product_title'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['weight'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['size'] . '</td><td style="padding:10px;border:1px solid #ddd;">' . $orderItem['qty'] . '</td>';
             $message .= '</tr>';
         };
         $message .= '</tbody>';
         $message .= '</table>';
-        $message .= 'Best regards, The Simon Howie Team.
-        ';
+        $message .= '<br>';
+        $message .= '<br>';
+        $message .= 'For collection times please see our <a href="https://www.thescottishbutcher.com/local-butchers-perth-auchterarder/locations-opening-times/">website</a><br>';
+        $message .= 'A problem with your order or its collection? Please contact us at <a href="mailto:collect@simonhowiefoods.co.uk">collect@simonhowiefoods.co.uk</a><br>';
+        $message .= 'We look forward to welcoming you back to one of our stores.<br>';
+        $message .= 'Many thanks, The Simon Howie Team.<br>';
+        $message .= '</div>';
+        $message .= '</div>';
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
         wp_mail($to, $subject, $message, $headers);
@@ -419,11 +459,12 @@ class OrderController
         $to = $order->getEmail();
         $subject = 'Thank you for collecting your Simon Howie Order';
         $message = '
-        Dear ' . $order->getName() . '
-        
-        Thank you for collecting your order.
-        
-        ';
+        <img src="https://s3-eu-west-1.amazonaws.com/blue2digital/pex/simonhowie/2019/05/02152443/SimonHowie-logo-on-white.png" style="display:block;width:300px;height:auto;margin:15px 0;" alt="Simon Howie Logo">
+        Dear ' . $order->getName() . '<br>Thank you for collecting your recent order.<br>';
+        $message .= 'We hope that you like our new Click & Collect service, if you have any feedback about our products please leave a review <a href="https://www.thescottishbutcher.com/review-our-products/">here</a>';
+        $message .= 'If you have had a problem with your order or its collection, please contact us at <a href="mailto:collect@simonhowiefoods.co.uk">collect@simonhowiefoods.co.uk</a><br>';
+        $message .= 'We look forward to welcoming you back to one of our stores.<br>';
+        $message .= 'Many thanks, The Simon Howie Team.<br>';
 
         $headers = ['Content-Type: text/html; charset=UTF-8'];
 
